@@ -25,7 +25,6 @@ from cliff.formatters import table
 from cliff import lister
 from cliff import show
 from oslo_serialization import jsonutils
-from oslo_utils import strutils
 import six
 
 from tackerclient.common._i18n import _
@@ -386,8 +385,6 @@ class TackerCommand(command.OpenStackCommand):
     def format_output_data(self, data):
         # Modify data to make it more readable
         if self.resource in data:
-            data[self.resource] = strutils.mask_dict_password(
-                data[self.resource])
             for k, v in six.iteritems(data[self.resource]):
                 if isinstance(v, list):
                     value = '\n'.join(jsonutils.dumps(
@@ -649,6 +646,10 @@ class ShowCommand(TackerCommand, show.ShowOne):
     log = None
     allow_names = True
 
+    def get_id(self):
+        if self.resource:
+            return self.resource.upper()
+
     def get_parser(self, prog_name):
         parser = super(ShowCommand, self).get_parser(prog_name)
         add_show_list_common_argument(parser)
@@ -657,7 +658,7 @@ class ShowCommand(TackerCommand, show.ShowOne):
         else:
             help_str = _('ID of %s to look up')
         parser.add_argument(
-            'id', metavar=self.resource.upper(),
+            'id', metavar=self.get_id(),
             help=help_str % self.resource)
         return parser
 
